@@ -197,7 +197,11 @@ Keys {unselected_keys}, are unselected in source
 
     # Aggregations=None is only valid if group_by is Entities
     if aggregations is None:
-        assert not any([s.events for s in sources]), "You can only set aggregations=None in an EntitySource"
+        is_events = any([s.events for s in sources])
+        has_mutations = any([(s.entities.mutationTable is not None or s.entities.mutationTopic is not None)
+                             for s in sources])
+        assert not (is_events or has_mutations), \
+            "You can only set aggregations=None in an EntitySource without mutations"
     else:
         columns = set([c for src in sources for c in utils.get_columns(src)])
         for agg in aggregations:
@@ -288,6 +292,7 @@ def GroupBy(sources: Union[List[_ANY_SOURCE_TYPE], _ANY_SOURCE_TYPE],
             output_namespace: str = None,
             accuracy: ttypes.Accuracy = None,
             lag: int = 0,
+            offline_schedule: str = '@daily',
             name: str = None,
             tags: Dict[str, str] = None,
             **kwargs) -> ttypes.GroupBy:
@@ -370,6 +375,14 @@ def GroupBy(sources: Union[List[_ANY_SOURCE_TYPE], _ANY_SOURCE_TYPE],
         Param that goes into customJson. You can pull this out of the json at path "metaData.customJson.lag"
         This is used by airflow integration to pick an older hive partition to wait on.
     :type lag: int
+    :param offline_schedule:
+         the offline schedule interval for batch jobs. Below is the equivalent of the cron tab commands
+        '@hourly': '0 * * * *',
+        '@daily': '0 0 * * *',
+        '@weekly': '0 0 * * 0',
+        '@monthly': '0 0 1 * *',
+        '@yearly': '0 0 1 1 *',
+    :type offline_schedule: str
     :param kwargs:
         Additional properties that would be passed to run.py if specified under additional_args property.
         And provides an option to pass custom values to the processing logic.
@@ -445,7 +458,8 @@ def GroupBy(sources: Union[List[_ANY_SOURCE_TYPE], _ANY_SOURCE_TYPE],
         dependencies=deps,
         modeToEnvMap=env,
         tableProperties=table_properties,
-        team=team)
+        team=team,
+        offlineSchedule=offline_schedule)
 
     group_by = ttypes.GroupBy(
         sources=sources,
