@@ -89,7 +89,7 @@ def get_streaming_sources(group_by: api.GroupBy) -> List[api.Source]:
 def is_streaming(source: api.Source) -> bool:
     """Checks if the source has streaming enabled."""
     return (source.entities and source.entities.mutationTopic is not None) or \
-        (source.events and source.events.topic is not None)
+           (source.events and source.events.topic is not None)
 
 
 def get_underlying_source(source: api.Source) -> Union[api.EventSource, api.EntitySource]:
@@ -128,11 +128,35 @@ def get_mod_name_from_gc(obj, mod_prefix):
     return mod_name
 
 
-def get_staging_query_output_table_name(staging_query: api.StagingQuery):
+def __set_name(obj, cls, mod_prefix):
+    module = importlib.import_module(get_mod_name_from_gc(obj, mod_prefix))
+    eo.import_module_set_name(module, cls)
+
+
+def output_table_name(obj, full_name: bool):
+    table_name = obj.metaData.name.replace('.', '_')
+    db = obj.metaData.outputNamespace
+    db = db or "{{ db }}"
+    if full_name:
+        return db + "." + table_name
+    else:
+        return table_name
+
+
+def log_table_name(obj, full_name: bool = False):
+    return output_table_name(obj, full_name=full_name) + "_logged"
+
+
+def get_staging_query_output_table_name(staging_query: api.StagingQuery, full_name: bool = False):
     """generate output table name for staging query job"""
-    staging_query_module = importlib.import_module(get_mod_name_from_gc(staging_query, "staging_queries"))
-    eo.import_module_set_name(staging_query_module, api.StagingQuery)
-    return staging_query.metaData.name.replace('.', '_')
+    __set_name(staging_query, api.StagingQuery, "staging_queries")
+    return output_table_name(staging_query, full_name=full_name)
+
+
+def get_join_output_table_name(join: api.Join, full_name: bool):
+    """generate output table name for staging query job"""
+    __set_name(join, api.Join, "joins")
+    return output_table_name(join, full_name=full_name)
 
 
 def get_dependencies(
@@ -167,6 +191,20 @@ def get_dependencies(
     return [json.dumps(res) for res in result]
 
 
+def get_label_table_dependencies(label_part) -> List[str]:
+    label_info = [(label.groupBy.sources, label.groupBy.metaData) for label in label_part.labels]
+    label_info = [(source, meta_data) for (sources, meta_data) in label_info for source in sources]
+    label_dependencies = [dep for (source, meta_data) in label_info for dep in
+                          get_dependencies(src=source, meta_data=meta_data)]
+    label_dependencies.append(
+        json.dumps({
+            "name": "wait_for_{{ join_backfill_table }}",
+            "spec": "{{ join_backfill_table }}/ds={{ ds }}"
+        })
+    )
+    return label_dependencies
+
+
 def wait_for_simple_schema(table, lag, start, end):
     if not table:
         return None
